FVMessages class
Simple localization wrapper using intl package.
Consumers should initialize locale (Intl.defaultLocale) and provide
ARB/intl messages when publishing.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
invalidCnic(
) → String -
invalidDate(
) → String -
invalidEmail(
) → String -
invalidPhone(
) → String -
invalidTime(
) → String -
passwordNeedsDigit(
) → String -
passwordNeedsLowercase(
) → String -
passwordNeedsSpecialChar(
) → String -
passwordNeedsUppercase(
) → String -
passwordTooShort(
int minLength) → String -
required(
) → String -
tooLong(
int max) → String -
tooShort(
int min) → String -
weakPassword(
) → String